# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/reach_plan_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import reach_plan_ad_length_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__ad__length__pb2
from google.ads.google_ads.v2.proto.enums import reach_plan_age_range_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__age__range__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/reach_plan_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\025ReachPlanServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/services/reach_plan_service.proto\x12 google.ads.googleads.v2.services\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a>google/ads/googleads_v2/proto/enums/reach_plan_ad_length.proto\x1a>google/ads/googleads_v2/proto/enums/reach_plan_age_range.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/api/client.proto\"\x1f\n\x1dListPlannableLocationsRequest\"r\n\x1eListPlannableLocationsResponse\x12P\n\x13plannable_locations\x18\x01 \x03(\x0b\x32\x33.google.ads.googleads.v2.services.PlannableLocation\"\xa1\x01\n\x11PlannableLocation\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x11parent_country_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"[\n\x1cListPlannableProductsRequest\x12;\n\x15plannable_location_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"l\n\x1dListPlannableProductsResponse\x12K\n\x10product_metadata\x18\x01 \x03(\x0b\x32\x31.google.ads.googleads.v2.services.ProductMetadata\"\xa2\x01\n\x0fProductMetadata\x12<\n\x16plannable_product_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Q\n\x13plannable_targeting\x18\x02 \x01(\x0b\x32\x34.google.ads.googleads.v2.services.PlannableTargeting\"\xea\x01\n\x12PlannableTargeting\x12Z\n\nage_ranges\x18\x01 \x03(\x0e\x32\x46.google.ads.googleads.v2.enums.ReachPlanAgeRangeEnum.ReachPlanAgeRange\x12;\n\x07genders\x18\x02 \x03(\x0b\x32*.google.ads.googleads.v2.common.GenderInfo\x12;\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32*.google.ads.googleads.v2.common.DeviceInfo\"\x9f\x02\n\x1eGenerateProductMixIdeasRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12;\n\x15plannable_location_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rcurrency_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\rbudget_micros\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x0bpreferences\x18\x05 \x01(\x0b\x32-.google.ads.googleads.v2.services.Preferences\"\xc1\x02\n\x0bPreferences\x12\x30\n\x0cis_skippable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11starts_with_sound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12Y\n\tad_length\x18\x03 \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.ReachPlanAdLengthEnum.ReachPlanAdLength\x12\x34\n\x10top_content_only\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14has_guaranteed_price\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"r\n\x1fGenerateProductMixIdeasResponse\x12O\n\x12product_allocation\x18\x01 \x03(\x0b\x32\x33.google.ads.googleads.v2.services.ProductAllocation\"\x85\x01\n\x11ProductAllocation\x12<\n\x16plannable_product_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\rbudget_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xbc\x03\n\x1cGenerateReachForecastRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x33\n\rcurrency_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x11\x63\x61mpaign_duration\x18\x03 \x01(\x0b\x32\x32.google.ads.googleads.v2.services.CampaignDuration\x12\x39\n\x14\x63ookie_frequency_cap\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12<\n\x17min_effective_frequency\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12>\n\ttargeting\x18\x06 \x01(\x0b\x32+.google.ads.googleads.v2.services.Targeting\x12J\n\x10planned_products\x18\x07 \x03(\x0b\x32\x30.google.ads.googleads.v2.services.PlannedProduct\"\x9d\x02\n\tTargeting\x12;\n\x15plannable_location_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Y\n\tage_range\x18\x02 \x01(\x0e\x32\x46.google.ads.googleads.v2.enums.ReachPlanAgeRangeEnum.ReachPlanAgeRange\x12;\n\x07genders\x18\x03 \x03(\x0b\x32*.google.ads.googleads.v2.common.GenderInfo\x12;\n\x07\x64\x65vices\x18\x04 \x03(\x0b\x32*.google.ads.googleads.v2.common.DeviceInfo\"I\n\x10\x43\x61mpaignDuration\x12\x35\n\x10\x64uration_in_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\x82\x01\n\x0ePlannedProduct\x12<\n\x16plannable_product_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\rbudget_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xc1\x01\n\x1dGenerateReachForecastResponse\x12]\n\x1aon_target_audience_metrics\x18\x01 \x01(\x0b\x32\x39.google.ads.googleads.v2.services.OnTargetAudienceMetrics\x12\x41\n\x0breach_curve\x18\x02 \x01(\x0b\x32,.google.ads.googleads.v2.services.ReachCurve\"V\n\nReachCurve\x12H\n\x0freach_forecasts\x18\x01 \x03(\x0b\x32/.google.ads.googleads.v2.services.ReachForecast\"\xdc\x01\n\rReachForecast\x12\x30\n\x0b\x63ost_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x08\x66orecast\x18\x02 \x01(\x0b\x32*.google.ads.googleads.v2.services.Forecast\x12[\n\x1e\x66orecasted_product_allocations\x18\x03 \x03(\x0b\x32\x33.google.ads.googleads.v2.services.ProductAllocation\"\xe6\x01\n\x08\x46orecast\x12\x34\n\x0fon_target_reach\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x0btotal_reach\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15on_target_impressions\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x11total_impressions\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x90\x01\n\x17OnTargetAudienceMetrics\x12:\n\x15youtube_audience_size\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x63\x65nsus_audience_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value2\xf3\x06\n\x10ReachPlanService\x12\xc2\x01\n\x16ListPlannableLocations\x12?.google.ads.googleads.v2.services.ListPlannableLocationsRequest\x1a@.google.ads.googleads.v2.services.ListPlannableLocationsResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v2:listPlannableLocations:\x01*\x12\xbe\x01\n\x15ListPlannableProducts\x12>.google.ads.googleads.v2.services.ListPlannableProductsRequest\x1a?.google.ads.googleads.v2.services.ListPlannableProductsResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v2:listPlannableProducts:\x01*\x12\xe0\x01\n\x17GenerateProductMixIdeas\x12@.google.ads.googleads.v2.services.GenerateProductMixIdeasRequest\x1a\x41.google.ads.googleads.v2.services.GenerateProductMixIdeasResponse\"@\x82\xd3\xe4\x93\x02:\"5/v2/customers/{customer_id=*}:generateProductMixIdeas:\x01*\x12\xd8\x01\n\x15GenerateReachForecast\x12>.google.ads.googleads.v2.services.GenerateReachForecastRequest\x1a?.google.ads.googleads.v2.services.GenerateReachForecastResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v2/customers/{customer_id=*}:generateReachForecast:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\xfc\x01\n$com.google.ads.googleads.v2.servicesB\x15ReachPlanServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__ad__length__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__age__range__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_LISTPLANNABLELOCATIONSREQUEST = _descriptor.Descriptor(
  name='ListPlannableLocationsRequest',
  full_name='google.ads.googleads.v2.services.ListPlannableLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=400,
)


_LISTPLANNABLELOCATIONSRESPONSE = _descriptor.Descriptor(
  name='ListPlannableLocationsResponse',
  full_name='google.ads.googleads.v2.services.ListPlannableLocationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_locations', full_name='google.ads.googleads.v2.services.ListPlannableLocationsResponse.plannable_locations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=516,
)


_PLANNABLELOCATION = _descriptor.Descriptor(
  name='PlannableLocation',
  full_name='google.ads.googleads.v2.services.PlannableLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.services.PlannableLocation.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.services.PlannableLocation.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_country_id', full_name='google.ads.googleads.v2.services.PlannableLocation.parent_country_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=680,
)


_LISTPLANNABLEPRODUCTSREQUEST = _descriptor.Descriptor(
  name='ListPlannableProductsRequest',
  full_name='google.ads.googleads.v2.services.ListPlannableProductsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_location_id', full_name='google.ads.googleads.v2.services.ListPlannableProductsRequest.plannable_location_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=773,
)


_LISTPLANNABLEPRODUCTSRESPONSE = _descriptor.Descriptor(
  name='ListPlannableProductsResponse',
  full_name='google.ads.googleads.v2.services.ListPlannableProductsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_metadata', full_name='google.ads.googleads.v2.services.ListPlannableProductsResponse.product_metadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=883,
)


_PRODUCTMETADATA = _descriptor.Descriptor(
  name='ProductMetadata',
  full_name='google.ads.googleads.v2.services.ProductMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_product_code', full_name='google.ads.googleads.v2.services.ProductMetadata.plannable_product_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plannable_targeting', full_name='google.ads.googleads.v2.services.ProductMetadata.plannable_targeting', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=1048,
)


_PLANNABLETARGETING = _descriptor.Descriptor(
  name='PlannableTargeting',
  full_name='google.ads.googleads.v2.services.PlannableTargeting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='age_ranges', full_name='google.ads.googleads.v2.services.PlannableTargeting.age_ranges', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='genders', full_name='google.ads.googleads.v2.services.PlannableTargeting.genders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='devices', full_name='google.ads.googleads.v2.services.PlannableTargeting.devices', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1285,
)


_GENERATEPRODUCTMIXIDEASREQUEST = _descriptor.Descriptor(
  name='GenerateProductMixIdeasRequest',
  full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plannable_location_id', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest.plannable_location_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest.currency_code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='budget_micros', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest.budget_micros', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferences', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasRequest.preferences', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1575,
)


_PREFERENCES = _descriptor.Descriptor(
  name='Preferences',
  full_name='google.ads.googleads.v2.services.Preferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_skippable', full_name='google.ads.googleads.v2.services.Preferences.is_skippable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='starts_with_sound', full_name='google.ads.googleads.v2.services.Preferences.starts_with_sound', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_length', full_name='google.ads.googleads.v2.services.Preferences.ad_length', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_content_only', full_name='google.ads.googleads.v2.services.Preferences.top_content_only', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_guaranteed_price', full_name='google.ads.googleads.v2.services.Preferences.has_guaranteed_price', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1899,
)


_GENERATEPRODUCTMIXIDEASRESPONSE = _descriptor.Descriptor(
  name='GenerateProductMixIdeasResponse',
  full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='product_allocation', full_name='google.ads.googleads.v2.services.GenerateProductMixIdeasResponse.product_allocation', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1901,
  serialized_end=2015,
)


_PRODUCTALLOCATION = _descriptor.Descriptor(
  name='ProductAllocation',
  full_name='google.ads.googleads.v2.services.ProductAllocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_product_code', full_name='google.ads.googleads.v2.services.ProductAllocation.plannable_product_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='budget_micros', full_name='google.ads.googleads.v2.services.ProductAllocation.budget_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2151,
)


_GENERATEREACHFORECASTREQUEST = _descriptor.Descriptor(
  name='GenerateReachForecastRequest',
  full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.currency_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_duration', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.campaign_duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookie_frequency_cap', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.cookie_frequency_cap', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_effective_frequency', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.min_effective_frequency', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeting', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.targeting', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='planned_products', full_name='google.ads.googleads.v2.services.GenerateReachForecastRequest.planned_products', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2598,
)


_TARGETING = _descriptor.Descriptor(
  name='Targeting',
  full_name='google.ads.googleads.v2.services.Targeting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_location_id', full_name='google.ads.googleads.v2.services.Targeting.plannable_location_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age_range', full_name='google.ads.googleads.v2.services.Targeting.age_range', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='genders', full_name='google.ads.googleads.v2.services.Targeting.genders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='devices', full_name='google.ads.googleads.v2.services.Targeting.devices', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2601,
  serialized_end=2886,
)


_CAMPAIGNDURATION = _descriptor.Descriptor(
  name='CampaignDuration',
  full_name='google.ads.googleads.v2.services.CampaignDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration_in_days', full_name='google.ads.googleads.v2.services.CampaignDuration.duration_in_days', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2888,
  serialized_end=2961,
)


_PLANNEDPRODUCT = _descriptor.Descriptor(
  name='PlannedProduct',
  full_name='google.ads.googleads.v2.services.PlannedProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plannable_product_code', full_name='google.ads.googleads.v2.services.PlannedProduct.plannable_product_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='budget_micros', full_name='google.ads.googleads.v2.services.PlannedProduct.budget_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2964,
  serialized_end=3094,
)


_GENERATEREACHFORECASTRESPONSE = _descriptor.Descriptor(
  name='GenerateReachForecastResponse',
  full_name='google.ads.googleads.v2.services.GenerateReachForecastResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='on_target_audience_metrics', full_name='google.ads.googleads.v2.services.GenerateReachForecastResponse.on_target_audience_metrics', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reach_curve', full_name='google.ads.googleads.v2.services.GenerateReachForecastResponse.reach_curve', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3097,
  serialized_end=3290,
)


_REACHCURVE = _descriptor.Descriptor(
  name='ReachCurve',
  full_name='google.ads.googleads.v2.services.ReachCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reach_forecasts', full_name='google.ads.googleads.v2.services.ReachCurve.reach_forecasts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3292,
  serialized_end=3378,
)


_REACHFORECAST = _descriptor.Descriptor(
  name='ReachForecast',
  full_name='google.ads.googleads.v2.services.ReachForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cost_micros', full_name='google.ads.googleads.v2.services.ReachForecast.cost_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forecast', full_name='google.ads.googleads.v2.services.ReachForecast.forecast', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forecasted_product_allocations', full_name='google.ads.googleads.v2.services.ReachForecast.forecasted_product_allocations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3381,
  serialized_end=3601,
)


_FORECAST = _descriptor.Descriptor(
  name='Forecast',
  full_name='google.ads.googleads.v2.services.Forecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='on_target_reach', full_name='google.ads.googleads.v2.services.Forecast.on_target_reach', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_reach', full_name='google.ads.googleads.v2.services.Forecast.total_reach', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on_target_impressions', full_name='google.ads.googleads.v2.services.Forecast.on_target_impressions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_impressions', full_name='google.ads.googleads.v2.services.Forecast.total_impressions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3604,
  serialized_end=3834,
)


_ONTARGETAUDIENCEMETRICS = _descriptor.Descriptor(
  name='OnTargetAudienceMetrics',
  full_name='google.ads.googleads.v2.services.OnTargetAudienceMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='youtube_audience_size', full_name='google.ads.googleads.v2.services.OnTargetAudienceMetrics.youtube_audience_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='census_audience_size', full_name='google.ads.googleads.v2.services.OnTargetAudienceMetrics.census_audience_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3837,
  serialized_end=3981,
)

_LISTPLANNABLELOCATIONSRESPONSE.fields_by_name['plannable_locations'].message_type = _PLANNABLELOCATION
_PLANNABLELOCATION.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PLANNABLELOCATION.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PLANNABLELOCATION.fields_by_name['parent_country_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LISTPLANNABLEPRODUCTSREQUEST.fields_by_name['plannable_location_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LISTPLANNABLEPRODUCTSRESPONSE.fields_by_name['product_metadata'].message_type = _PRODUCTMETADATA
_PRODUCTMETADATA.fields_by_name['plannable_product_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTMETADATA.fields_by_name['plannable_targeting'].message_type = _PLANNABLETARGETING
_PLANNABLETARGETING.fields_by_name['age_ranges'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__age__range__pb2._REACHPLANAGERANGEENUM_REACHPLANAGERANGE
_PLANNABLETARGETING.fields_by_name['genders'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._GENDERINFO
_PLANNABLETARGETING.fields_by_name['devices'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._DEVICEINFO
_GENERATEPRODUCTMIXIDEASREQUEST.fields_by_name['plannable_location_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEPRODUCTMIXIDEASREQUEST.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEPRODUCTMIXIDEASREQUEST.fields_by_name['budget_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GENERATEPRODUCTMIXIDEASREQUEST.fields_by_name['preferences'].message_type = _PREFERENCES
_PREFERENCES.fields_by_name['is_skippable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PREFERENCES.fields_by_name['starts_with_sound'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PREFERENCES.fields_by_name['ad_length'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__ad__length__pb2._REACHPLANADLENGTHENUM_REACHPLANADLENGTH
_PREFERENCES.fields_by_name['top_content_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_PREFERENCES.fields_by_name['has_guaranteed_price'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GENERATEPRODUCTMIXIDEASRESPONSE.fields_by_name['product_allocation'].message_type = _PRODUCTALLOCATION
_PRODUCTALLOCATION.fields_by_name['plannable_product_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTALLOCATION.fields_by_name['budget_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GENERATEREACHFORECASTREQUEST.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEREACHFORECASTREQUEST.fields_by_name['campaign_duration'].message_type = _CAMPAIGNDURATION
_GENERATEREACHFORECASTREQUEST.fields_by_name['cookie_frequency_cap'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GENERATEREACHFORECASTREQUEST.fields_by_name['min_effective_frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GENERATEREACHFORECASTREQUEST.fields_by_name['targeting'].message_type = _TARGETING
_GENERATEREACHFORECASTREQUEST.fields_by_name['planned_products'].message_type = _PLANNEDPRODUCT
_TARGETING.fields_by_name['plannable_location_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TARGETING.fields_by_name['age_range'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_reach__plan__age__range__pb2._REACHPLANAGERANGEENUM_REACHPLANAGERANGE
_TARGETING.fields_by_name['genders'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._GENDERINFO
_TARGETING.fields_by_name['devices'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._DEVICEINFO
_CAMPAIGNDURATION.fields_by_name['duration_in_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_PLANNEDPRODUCT.fields_by_name['plannable_product_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PLANNEDPRODUCT.fields_by_name['budget_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GENERATEREACHFORECASTRESPONSE.fields_by_name['on_target_audience_metrics'].message_type = _ONTARGETAUDIENCEMETRICS
_GENERATEREACHFORECASTRESPONSE.fields_by_name['reach_curve'].message_type = _REACHCURVE
_REACHCURVE.fields_by_name['reach_forecasts'].message_type = _REACHFORECAST
_REACHFORECAST.fields_by_name['cost_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REACHFORECAST.fields_by_name['forecast'].message_type = _FORECAST
_REACHFORECAST.fields_by_name['forecasted_product_allocations'].message_type = _PRODUCTALLOCATION
_FORECAST.fields_by_name['on_target_reach'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FORECAST.fields_by_name['total_reach'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FORECAST.fields_by_name['on_target_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FORECAST.fields_by_name['total_impressions'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ONTARGETAUDIENCEMETRICS.fields_by_name['youtube_audience_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ONTARGETAUDIENCEMETRICS.fields_by_name['census_audience_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['ListPlannableLocationsRequest'] = _LISTPLANNABLELOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPlannableLocationsResponse'] = _LISTPLANNABLELOCATIONSRESPONSE
DESCRIPTOR.message_types_by_name['PlannableLocation'] = _PLANNABLELOCATION
DESCRIPTOR.message_types_by_name['ListPlannableProductsRequest'] = _LISTPLANNABLEPRODUCTSREQUEST
DESCRIPTOR.message_types_by_name['ListPlannableProductsResponse'] = _LISTPLANNABLEPRODUCTSRESPONSE
DESCRIPTOR.message_types_by_name['ProductMetadata'] = _PRODUCTMETADATA
DESCRIPTOR.message_types_by_name['PlannableTargeting'] = _PLANNABLETARGETING
DESCRIPTOR.message_types_by_name['GenerateProductMixIdeasRequest'] = _GENERATEPRODUCTMIXIDEASREQUEST
DESCRIPTOR.message_types_by_name['Preferences'] = _PREFERENCES
DESCRIPTOR.message_types_by_name['GenerateProductMixIdeasResponse'] = _GENERATEPRODUCTMIXIDEASRESPONSE
DESCRIPTOR.message_types_by_name['ProductAllocation'] = _PRODUCTALLOCATION
DESCRIPTOR.message_types_by_name['GenerateReachForecastRequest'] = _GENERATEREACHFORECASTREQUEST
DESCRIPTOR.message_types_by_name['Targeting'] = _TARGETING
DESCRIPTOR.message_types_by_name['CampaignDuration'] = _CAMPAIGNDURATION
DESCRIPTOR.message_types_by_name['PlannedProduct'] = _PLANNEDPRODUCT
DESCRIPTOR.message_types_by_name['GenerateReachForecastResponse'] = _GENERATEREACHFORECASTRESPONSE
DESCRIPTOR.message_types_by_name['ReachCurve'] = _REACHCURVE
DESCRIPTOR.message_types_by_name['ReachForecast'] = _REACHFORECAST
DESCRIPTOR.message_types_by_name['Forecast'] = _FORECAST
DESCRIPTOR.message_types_by_name['OnTargetAudienceMetrics'] = _ONTARGETAUDIENCEMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPlannableLocationsRequest = _reflection.GeneratedProtocolMessageType('ListPlannableLocationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANNABLELOCATIONSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Request message for [ReachForecastService.ListPlannableLocations][]
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListPlannableLocationsRequest)
  ))
_sym_db.RegisterMessage(ListPlannableLocationsRequest)

ListPlannableLocationsResponse = _reflection.GeneratedProtocolMessageType('ListPlannableLocationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANNABLELOCATIONSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The list of plannable locations.
  
  
  Attributes:
      plannable_locations:
          The list of locations available for planning (Countries, DMAs,
          sub-countries). For locations like Countries, DMAs see https:/
          /developers.google.com/adwords/api/docs/appendix/geotargeting
          for more information.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListPlannableLocationsResponse)
  ))
_sym_db.RegisterMessage(ListPlannableLocationsResponse)

PlannableLocation = _reflection.GeneratedProtocolMessageType('PlannableLocation', (_message.Message,), dict(
  DESCRIPTOR = _PLANNABLELOCATION,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """A plannable location: a country, a DMA, a metro region, a tv region, a
  province.
  
  
  Attributes:
      id:
          The location identifier.
      name:
          The unique location name in english.
      parent_country_id:
          The parent country code, not present if location is a country.
          If present will always be a criterion id: additional
          information, such as country name are returned both via
          ListPlannableLocations or directly by accessing
          GeoTargetConstantService with the criterion id.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.PlannableLocation)
  ))
_sym_db.RegisterMessage(PlannableLocation)

ListPlannableProductsRequest = _reflection.GeneratedProtocolMessageType('ListPlannableProductsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANNABLEPRODUCTSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Request to list available products in a given location.
  
  
  Attributes:
      plannable_location_id:
          The ID of the selected location for planning. To list the
          available plannable location ids use ListPlannableLocations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListPlannableProductsRequest)
  ))
_sym_db.RegisterMessage(ListPlannableProductsRequest)

ListPlannableProductsResponse = _reflection.GeneratedProtocolMessageType('ListPlannableProductsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANNABLEPRODUCTSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """A response with all available products.
  
  
  Attributes:
      product_metadata:
          The list of products available for planning and related
          targeting metadata.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListPlannableProductsResponse)
  ))
_sym_db.RegisterMessage(ListPlannableProductsResponse)

ProductMetadata = _reflection.GeneratedProtocolMessageType('ProductMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTMETADATA,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The metadata associated with an available plannable product.
  
  
  Attributes:
      plannable_product_code:
          The code associated with the ad product. E.g. Trueview, Bumper
          To list the available plannable product codes use
          ListPlannableProducts.
      plannable_targeting:
          The allowed plannable targeting for this product.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ProductMetadata)
  ))
_sym_db.RegisterMessage(ProductMetadata)

PlannableTargeting = _reflection.GeneratedProtocolMessageType('PlannableTargeting', (_message.Message,), dict(
  DESCRIPTOR = _PLANNABLETARGETING,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The targeting for which traffic metrics will be reported.
  
  
  Attributes:
      age_ranges:
          Allowed plannable age ranges for the product for which metrics
          will be reported. Actual targeting is computed by mapping this
          age range onto standard Google common.AgeRangeInfo values.
      genders:
          Targetable genders for the ad product.
      devices:
          Targetable devices for the ad product.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.PlannableTargeting)
  ))
_sym_db.RegisterMessage(PlannableTargeting)

GenerateProductMixIdeasRequest = _reflection.GeneratedProtocolMessageType('GenerateProductMixIdeasRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEPRODUCTMIXIDEASREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Request message for [ReachForecastService.GenerateProductMixIdeas][].
  
  
  Attributes:
      customer_id:
          The ID of the customer.
      plannable_location_id:
          Required. The ID of the location, this is one of the ids
          returned by ListPlannableLocations.
      currency_code:
          Required. Currency code. Three-character ISO 4217 currency
          code.
      budget_micros:
          Required. Total budget. Amount in micros. One million is
          equivalent to one unit.
      preferences:
          The preferences of the suggested product mix. An unset
          preference is interpreted as all possible values are allowed,
          unless explicitly specified.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateProductMixIdeasRequest)
  ))
_sym_db.RegisterMessage(GenerateProductMixIdeasRequest)

Preferences = _reflection.GeneratedProtocolMessageType('Preferences', (_message.Message,), dict(
  DESCRIPTOR = _PREFERENCES,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Set of preferences about the planned mix.
  
  
  Attributes:
      is_skippable:
          True if ad skippable. If not set, default is any value.
      starts_with_sound:
          True if ad start with sound. If not set, default is any value.
      ad_length:
          The length of the ad. If not set, default is any value.
      top_content_only:
          True if ad will only show on the top content. If not set,
          default is false.
      has_guaranteed_price:
          True if the price guaranteed. The cost of serving the ad is
          agreed upfront and not subject to an auction. If not set,
          default is any value.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.Preferences)
  ))
_sym_db.RegisterMessage(Preferences)

GenerateProductMixIdeasResponse = _reflection.GeneratedProtocolMessageType('GenerateProductMixIdeasResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEPRODUCTMIXIDEASRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The suggested product mix.
  
  
  Attributes:
      product_allocation:
          A list of products (ad formats) and the associated budget
          allocation idea.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateProductMixIdeasResponse)
  ))
_sym_db.RegisterMessage(GenerateProductMixIdeasResponse)

ProductAllocation = _reflection.GeneratedProtocolMessageType('ProductAllocation', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTALLOCATION,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """An allocation of a part of the budget on a given product.
  
  
  Attributes:
      plannable_product_code:
          Selected product for planning. The product codes returned are
          within the set of the ones returned by ListPlannableProducts
          when using the same location id.
      budget_micros:
          The value to be allocated for the suggested product in
          requested currency. Amount in micros. One million is
          equivalent to one unit.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ProductAllocation)
  ))
_sym_db.RegisterMessage(ProductAllocation)

GenerateReachForecastRequest = _reflection.GeneratedProtocolMessageType('GenerateReachForecastRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEREACHFORECASTREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Request message for
  [ReachPlanService.GenerateReachForecast][google.ads.googleads.v2.services.ReachPlanService.GenerateReachForecast].
  
  
  Attributes:
      customer_id:
          The ID of the customer.
      currency_code:
          Required. The currency code. Three-character ISO 4217 currency
          code.
      campaign_duration:
          Campaign duration.
      cookie_frequency_cap:
          Desired cookie frequency cap that will be applied to each
          planned product. This is equivalent to the frequency cap
          exposed in Google Ads when creating a campaign, it represents
          the maximum number of times an ad can be shown to the same
          user. If not specified no cap is applied.
      min_effective_frequency:
          Desired minimum effective frequency (the number of times a
          person was exposed to the ad) for the reported reach metrics
          [1-10]. This won't affect the targeting, but just the
          reporting. If not specified, a default of 1 is applied.
      targeting:
          The targeting to be applied to all products selected in the
          product mix.  This is planned targeting: execution details
          might vary based on the advertising product, please consult an
          implementation specialist.  If no targeting dimensions are
          specified, then campaigns will target everywhere and everyone.
          See specific metrics for details on how targeting affects
          them.  In some cases, targeting may be overridden using the
          PlannedProduct.advanced\_product\_targeting field.
      planned_products:
          The product to be planned.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateReachForecastRequest)
  ))
_sym_db.RegisterMessage(GenerateReachForecastRequest)

Targeting = _reflection.GeneratedProtocolMessageType('Targeting', (_message.Message,), dict(
  DESCRIPTOR = _TARGETING,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The targeting for which traffic metrics will be reported.
  
  
  Attributes:
      plannable_location_id:
          Required. The ID of the selected location. Plannable locations
          ID can be obtained from ListPlannableLocations.
      age_range:
          Required Selected age range to be planned on.
      genders:
          Targetable genders for the ad product.
      devices:
          Targetable devices for the ad product.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.Targeting)
  ))
_sym_db.RegisterMessage(Targeting)

CampaignDuration = _reflection.GeneratedProtocolMessageType('CampaignDuration', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNDURATION,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The duration of a planned campaign.
  
  
  Attributes:
      duration_in_days:
          The duration value in days.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CampaignDuration)
  ))
_sym_db.RegisterMessage(CampaignDuration)

PlannedProduct = _reflection.GeneratedProtocolMessageType('PlannedProduct', (_message.Message,), dict(
  DESCRIPTOR = _PLANNEDPRODUCT,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """A product being planned for reach.
  
  
  Attributes:
      plannable_product_code:
          Required. Selected product for planning. Plannable products
          codes can be obtained from ListPlannableProducts.
      budget_micros:
          Required. Maximum budget allocation in micros for the selected
          product. The value is specified in the selected planning
          currency\_code. E.g. 1 000 000$ = 1 000 000 000 000 micros.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.PlannedProduct)
  ))
_sym_db.RegisterMessage(PlannedProduct)

GenerateReachForecastResponse = _reflection.GeneratedProtocolMessageType('GenerateReachForecastResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEREACHFORECASTRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Response message containing the generated reach curve.
  
  
  Attributes:
      on_target_audience_metrics:
          Reference on target audiences for this curve.
      reach_curve:
          The generated reach curve for the planned product mix.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateReachForecastResponse)
  ))
_sym_db.RegisterMessage(GenerateReachForecastResponse)

ReachCurve = _reflection.GeneratedProtocolMessageType('ReachCurve', (_message.Message,), dict(
  DESCRIPTOR = _REACHCURVE,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """The reach curve for the planned products.
  
  
  Attributes:
      reach_forecasts:
          All points on the reach curve.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ReachCurve)
  ))
_sym_db.RegisterMessage(ReachCurve)

ReachForecast = _reflection.GeneratedProtocolMessageType('ReachForecast', (_message.Message,), dict(
  DESCRIPTOR = _REACHFORECAST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """A point on reach curve.
  
  
  Attributes:
      cost_micros:
          The cost in micros.
      forecast:
          Forecasted traffic metrics for this point.
      forecasted_product_allocations:
          The forecasted allocation. This differs from the input
          allocation if one or more product cannot fulfill the budget
          because of limited inventory.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ReachForecast)
  ))
_sym_db.RegisterMessage(ReachForecast)

Forecast = _reflection.GeneratedProtocolMessageType('Forecast', (_message.Message,), dict(
  DESCRIPTOR = _FORECAST,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Forecasted traffic metrics for the planned products and targeting.
  
  
  Attributes:
      on_target_reach:
          Number of unique people reached at least
          GenerateReachForecastRequest.min\_effective\_frequency times
          that exactly matches the Targeting.
      total_reach:
          Total number of unique people reached at least
          GenerateReachForecastRequest.min\_effective\_frequency times.
          This includes people that may fall outside the specified
          Targeting.
      on_target_impressions:
          Number of ad impressions that exactly matches the Targeting.
      total_impressions:
          Total number of ad impressions. This includes impressions that
          may fall outside the specified Targeting, due to insufficent
          information on signed-in users.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.Forecast)
  ))
_sym_db.RegisterMessage(Forecast)

OnTargetAudienceMetrics = _reflection.GeneratedProtocolMessageType('OnTargetAudienceMetrics', (_message.Message,), dict(
  DESCRIPTOR = _ONTARGETAUDIENCEMETRICS,
  __module__ = 'google.ads.googleads_v2.proto.services.reach_plan_service_pb2'
  ,
  __doc__ = """Audience metrics for the planned products. These metrics consider the
  following targeting dimensions:
  
  -  Location
  -  PlannableAgeRange
  -  Gender
  
  
  Attributes:
      youtube_audience_size:
          Reference audience size matching the considered targeting for
          YouTube.
      census_audience_size:
          Reference audience size matching the considered targeting for
          Census.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.OnTargetAudienceMetrics)
  ))
_sym_db.RegisterMessage(OnTargetAudienceMetrics)


DESCRIPTOR._options = None

_REACHPLANSERVICE = _descriptor.ServiceDescriptor(
  name='ReachPlanService',
  full_name='google.ads.googleads.v2.services.ReachPlanService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=3984,
  serialized_end=4867,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPlannableLocations',
    full_name='google.ads.googleads.v2.services.ReachPlanService.ListPlannableLocations',
    index=0,
    containing_service=None,
    input_type=_LISTPLANNABLELOCATIONSREQUEST,
    output_type=_LISTPLANNABLELOCATIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v2:listPlannableLocations:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPlannableProducts',
    full_name='google.ads.googleads.v2.services.ReachPlanService.ListPlannableProducts',
    index=1,
    containing_service=None,
    input_type=_LISTPLANNABLEPRODUCTSREQUEST,
    output_type=_LISTPLANNABLEPRODUCTSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\036\"\031/v2:listPlannableProducts:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GenerateProductMixIdeas',
    full_name='google.ads.googleads.v2.services.ReachPlanService.GenerateProductMixIdeas',
    index=2,
    containing_service=None,
    input_type=_GENERATEPRODUCTMIXIDEASREQUEST,
    output_type=_GENERATEPRODUCTMIXIDEASRESPONSE,
    serialized_options=_b('\202\323\344\223\002:\"5/v2/customers/{customer_id=*}:generateProductMixIdeas:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GenerateReachForecast',
    full_name='google.ads.googleads.v2.services.ReachPlanService.GenerateReachForecast',
    index=3,
    containing_service=None,
    input_type=_GENERATEREACHFORECASTREQUEST,
    output_type=_GENERATEREACHFORECASTRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v2/customers/{customer_id=*}:generateReachForecast:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_REACHPLANSERVICE)

DESCRIPTOR.services_by_name['ReachPlanService'] = _REACHPLANSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/click_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import click_location_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/click_view.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\016ClickViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/resources/click_view.proto\x12!google.ads.googleads.v1.resources\x1a\x39google/ads/googleads_v1/proto/common/click_location.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x97\x02\n\tClickView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12+\n\x05gclid\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n\x10\x61rea_of_interest\x18\x03 \x01(\x0b\x32-.google.ads.googleads.v1.common.ClickLocation\x12K\n\x14location_of_presence\x18\x04 \x01(\x0b\x32-.google.ads.googleads.v1.common.ClickLocation\x12\x30\n\x0bpage_number\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\xfb\x01\n%com.google.ads.googleads.v1.resourcesB\x0e\x43lickViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CLICKVIEW = _descriptor.Descriptor(
  name='ClickView',
  full_name='google.ads.googleads.v1.resources.ClickView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.ClickView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gclid', full_name='google.ads.googleads.v1.resources.ClickView.gclid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='google.ads.googleads.v1.resources.ClickView.area_of_interest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_of_presence', full_name='google.ads.googleads.v1.resources.ClickView.location_of_presence', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number', full_name='google.ads.googleads.v1.resources.ClickView.page_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=496,
)

_CLICKVIEW.fields_by_name['gclid'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CLICKVIEW.fields_by_name['area_of_interest'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2._CLICKLOCATION
_CLICKVIEW.fields_by_name['location_of_presence'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_click__location__pb2._CLICKLOCATION
_CLICKVIEW.fields_by_name['page_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['ClickView'] = _CLICKVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClickView = _reflection.GeneratedProtocolMessageType('ClickView', (_message.Message,), dict(
  DESCRIPTOR = _CLICKVIEW,
  __module__ = 'google.ads.googleads_v1.proto.resources.click_view_pb2'
  ,
  __doc__ = """A click view with metrics aggregated at each click level, including both
  valid and invalid clicks. For non-Search campaigns, metrics.clicks
  represents the number of valid and invalid interactions.
  
  
  Attributes:
      resource_name:
          The resource name of the click view. Click view resource names
          have the form:  ``customers/{customer_id}/clickViews/{date
          (yyyy-MM-dd)}~{gclid}``
      gclid:
          The Google Click ID.
      area_of_interest:
          The location criteria matching the area of interest associated
          with the impression.
      location_of_presence:
          The location criteria matching the location of presence
          associated with the impression.
      page_number:
          Page number in search results where the ad was shown.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.ClickView)
  ))
_sym_db.RegisterMessage(ClickView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/extension_feed_item_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import extension_feed_item_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_extension__feed__item__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/extension_feed_item_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\035ExtensionFeedItemServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v1/proto/services/extension_feed_item_service.proto\x12 google.ads.googleads.v1.services\x1a\x41google/ads/googleads_v1/proto/resources/extension_feed_item.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\"4\n\x1bGetExtensionFeedItemRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x9f\x01\n\x1fMutateExtensionFeedItemsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12P\n\noperations\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v1.services.ExtensionFeedItemOperation\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xfc\x01\n\x1a\x45xtensionFeedItemOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x46\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x34.google.ads.googleads.v1.resources.ExtensionFeedItemH\x00\x12\x46\n\x06update\x18\x02 \x01(\x0b\x32\x34.google.ads.googleads.v1.resources.ExtensionFeedItemH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"t\n MutateExtensionFeedItemsResponse\x12P\n\x07results\x18\x02 \x03(\x0b\x32?.google.ads.googleads.v1.services.MutateExtensionFeedItemResult\"6\n\x1dMutateExtensionFeedItemResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xce\x03\n\x18\x45xtensionFeedItemService\x12\xc9\x01\n\x14GetExtensionFeedItem\x12=.google.ads.googleads.v1.services.GetExtensionFeedItemRequest\x1a\x34.google.ads.googleads.v1.resources.ExtensionFeedItem\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/{resource_name=customers/*/extensionFeedItems/*}\x12\xe5\x01\n\x18MutateExtensionFeedItems\x12\x41.google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest\x1a\x42.google.ads.googleads.v1.services.MutateExtensionFeedItemsResponse\"B\x82\xd3\xe4\x93\x02<\"7/v1/customers/{customer_id=*}/extensionFeedItems:mutate:\x01*B\x84\x02\n$com.google.ads.googleads.v1.servicesB\x1d\x45xtensionFeedItemServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_extension__feed__item__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GETEXTENSIONFEEDITEMREQUEST = _descriptor.Descriptor(
  name='GetExtensionFeedItemRequest',
  full_name='google.ads.googleads.v1.services.GetExtensionFeedItemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetExtensionFeedItemRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=325,
)


_MUTATEEXTENSIONFEEDITEMSREQUEST = _descriptor.Descriptor(
  name='MutateExtensionFeedItemsRequest',
  full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest.validate_only', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=487,
)


_EXTENSIONFEEDITEMOPERATION = _descriptor.Descriptor(
  name='ExtensionFeedItemOperation',
  full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v1.services.ExtensionFeedItemOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=490,
  serialized_end=742,
)


_MUTATEEXTENSIONFEEDITEMSRESPONSE = _descriptor.Descriptor(
  name='MutateExtensionFeedItemsResponse',
  full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=860,
)


_MUTATEEXTENSIONFEEDITEMRESULT = _descriptor.Descriptor(
  name='MutateExtensionFeedItemResult',
  full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.MutateExtensionFeedItemResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=916,
)

_MUTATEEXTENSIONFEEDITEMSREQUEST.fields_by_name['operations'].message_type = _EXTENSIONFEEDITEMOPERATION
_EXTENSIONFEEDITEMOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_EXTENSIONFEEDITEMOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_extension__feed__item__pb2._EXTENSIONFEEDITEM
_EXTENSIONFEEDITEMOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_extension__feed__item__pb2._EXTENSIONFEEDITEM
_EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _EXTENSIONFEEDITEMOPERATION.fields_by_name['create'])
_EXTENSIONFEEDITEMOPERATION.fields_by_name['create'].containing_oneof = _EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation']
_EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _EXTENSIONFEEDITEMOPERATION.fields_by_name['update'])
_EXTENSIONFEEDITEMOPERATION.fields_by_name['update'].containing_oneof = _EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation']
_EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation'].fields.append(
  _EXTENSIONFEEDITEMOPERATION.fields_by_name['remove'])
_EXTENSIONFEEDITEMOPERATION.fields_by_name['remove'].containing_oneof = _EXTENSIONFEEDITEMOPERATION.oneofs_by_name['operation']
_MUTATEEXTENSIONFEEDITEMSRESPONSE.fields_by_name['results'].message_type = _MUTATEEXTENSIONFEEDITEMRESULT
DESCRIPTOR.message_types_by_name['GetExtensionFeedItemRequest'] = _GETEXTENSIONFEEDITEMREQUEST
DESCRIPTOR.message_types_by_name['MutateExtensionFeedItemsRequest'] = _MUTATEEXTENSIONFEEDITEMSREQUEST
DESCRIPTOR.message_types_by_name['ExtensionFeedItemOperation'] = _EXTENSIONFEEDITEMOPERATION
DESCRIPTOR.message_types_by_name['MutateExtensionFeedItemsResponse'] = _MUTATEEXTENSIONFEEDITEMSRESPONSE
DESCRIPTOR.message_types_by_name['MutateExtensionFeedItemResult'] = _MUTATEEXTENSIONFEEDITEMRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetExtensionFeedItemRequest = _reflection.GeneratedProtocolMessageType('GetExtensionFeedItemRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETEXTENSIONFEEDITEMREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.extension_feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [ExtensionFeedItemService.GetExtensionFeedItem][google.ads.googleads.v1.services.ExtensionFeedItemService.GetExtensionFeedItem].
  
  
  Attributes:
      resource_name:
          The resource name of the extension feed item to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetExtensionFeedItemRequest)
  ))
_sym_db.RegisterMessage(GetExtensionFeedItemRequest)

MutateExtensionFeedItemsRequest = _reflection.GeneratedProtocolMessageType('MutateExtensionFeedItemsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEEXTENSIONFEEDITEMSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.extension_feed_item_service_pb2'
  ,
  __doc__ = """Request message for
  [ExtensionFeedItemService.MutateExtensionFeedItems][google.ads.googleads.v1.services.ExtensionFeedItemService.MutateExtensionFeedItems].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose extension feed items are being
          modified.
      operations:
          The list of operations to perform on individual extension feed
          items.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateExtensionFeedItemsRequest)
  ))
_sym_db.RegisterMessage(MutateExtensionFeedItemsRequest)

ExtensionFeedItemOperation = _reflection.GeneratedProtocolMessageType('ExtensionFeedItemOperation', (_message.Message,), dict(
  DESCRIPTOR = _EXTENSIONFEEDITEMOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.extension_feed_item_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an extension feed item.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          extension feed item.
      update:
          Update operation: The extension feed item is expected to have
          a valid resource name.
      remove:
          Remove operation: A resource name for the removed extension
          feed item is expected, in this format:
          ``customers/{customer_id}/extensionFeedItems/{feed_item_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ExtensionFeedItemOperation)
  ))
_sym_db.RegisterMessage(ExtensionFeedItemOperation)

MutateExtensionFeedItemsResponse = _reflection.GeneratedProtocolMessageType('MutateExtensionFeedItemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEEXTENSIONFEEDITEMSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.extension_feed_item_service_pb2'
  ,
  __doc__ = """Response message for an extension feed item mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateExtensionFeedItemsResponse)
  ))
_sym_db.RegisterMessage(MutateExtensionFeedItemsResponse)

MutateExtensionFeedItemResult = _reflection.GeneratedProtocolMessageType('MutateExtensionFeedItemResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEEXTENSIONFEEDITEMRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.extension_feed_item_service_pb2'
  ,
  __doc__ = """The result for the extension feed item mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.MutateExtensionFeedItemResult)
  ))
_sym_db.RegisterMessage(MutateExtensionFeedItemResult)


DESCRIPTOR._options = None

_EXTENSIONFEEDITEMSERVICE = _descriptor.ServiceDescriptor(
  name='ExtensionFeedItemService',
  full_name='google.ads.googleads.v1.services.ExtensionFeedItemService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=919,
  serialized_end=1381,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetExtensionFeedItem',
    full_name='google.ads.googleads.v1.services.ExtensionFeedItemService.GetExtensionFeedItem',
    index=0,
    containing_service=None,
    input_type=_GETEXTENSIONFEEDITEMREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_extension__feed__item__pb2._EXTENSIONFEEDITEM,
    serialized_options=_b('\202\323\344\223\0026\0224/v1/{resource_name=customers/*/extensionFeedItems/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateExtensionFeedItems',
    full_name='google.ads.googleads.v1.services.ExtensionFeedItemService.MutateExtensionFeedItems',
    index=1,
    containing_service=None,
    input_type=_MUTATEEXTENSIONFEEDITEMSREQUEST,
    output_type=_MUTATEEXTENSIONFEEDITEMSRESPONSE,
    serialized_options=_b('\202\323\344\223\002<\"7/v1/customers/{customer_id=*}/extensionFeedItems:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSIONFEEDITEMSERVICE)

DESCRIPTOR.services_by_name['ExtensionFeedItemService'] = _EXTENSIONFEEDITEMSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/age_range_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/age_range_type.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\021AgeRangeTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/enums/age_range_type.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xe9\x01\n\x10\x41geRangeTypeEnum\"\xd4\x01\n\x0c\x41geRangeType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x15\n\x0f\x41GE_RANGE_18_24\x10\xd9\xd9\x1e\x12\x15\n\x0f\x41GE_RANGE_25_34\x10\xda\xd9\x1e\x12\x15\n\x0f\x41GE_RANGE_35_44\x10\xdb\xd9\x1e\x12\x15\n\x0f\x41GE_RANGE_45_54\x10\xdc\xd9\x1e\x12\x15\n\x0f\x41GE_RANGE_55_64\x10\xdd\xd9\x1e\x12\x15\n\x0f\x41GE_RANGE_65_UP\x10\xde\xd9\x1e\x12\x1c\n\x16\x41GE_RANGE_UNDETERMINED\x10\xbf\xe1\x1e\x42\xe6\x01\n!com.google.ads.googleads.v1.enumsB\x11\x41geRangeTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_AGERANGETYPEENUM_AGERANGETYPE = _descriptor.EnumDescriptor(
  name='AgeRangeType',
  full_name='google.ads.googleads.v1.enums.AgeRangeTypeEnum.AgeRangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_18_24', index=2, number=503001,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_25_34', index=3, number=503002,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_35_44', index=4, number=503003,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_45_54', index=5, number=503004,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_55_64', index=6, number=503005,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_65_UP', index=7, number=503006,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE_UNDETERMINED', index=8, number=503999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=143,
  serialized_end=355,
)
_sym_db.RegisterEnumDescriptor(_AGERANGETYPEENUM_AGERANGETYPE)


_AGERANGETYPEENUM = _descriptor.Descriptor(
  name='AgeRangeTypeEnum',
  full_name='google.ads.googleads.v1.enums.AgeRangeTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AGERANGETYPEENUM_AGERANGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=355,
)

_AGERANGETYPEENUM_AGERANGETYPE.containing_type = _AGERANGETYPEENUM
DESCRIPTOR.message_types_by_name['AgeRangeTypeEnum'] = _AGERANGETYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgeRangeTypeEnum = _reflection.GeneratedProtocolMessageType('AgeRangeTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _AGERANGETYPEENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.age_range_type_pb2'
  ,
  __doc__ = """Container for enum describing the type of demographic age ranges.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.AgeRangeTypeEnum)
  ))
_sym_db.RegisterMessage(AgeRangeTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/google_ads_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import google_ads_field_category_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__category__pb2
from google.ads.google_ads.v2.proto.enums import google_ads_field_data_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/google_ads_field.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\023GoogleAdsFieldProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/resources/google_ads_field.proto\x12!google.ads.googleads.v2.resources\x1a\x43google/ads/googleads_v2/proto/enums/google_ads_field_category.proto\x1a\x44google/ads/googleads_v2/proto/enums/google_ads_field_data_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8f\x06\n\x0eGoogleAdsField\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x62\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32P.google.ads.googleads.v2.enums.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory\x12.\n\nselectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nfilterable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08sortable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x0fselectable_with\x18\x07 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x61ttribute_resources\x18\x08 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07metrics\x18\t \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08segments\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x65num_values\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x63\n\tdata_type\x18\x0c \x01(\x0e\x32P.google.ads.googleads.v2.enums.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType\x12.\n\x08type_url\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\x0bis_repeated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x80\x02\n%com.google.ads.googleads.v2.resourcesB\x13GoogleAdsFieldProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GOOGLEADSFIELD = _descriptor.Descriptor(
  name='GoogleAdsField',
  full_name='google.ads.googleads.v2.resources.GoogleAdsField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.GoogleAdsField.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.GoogleAdsField.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='google.ads.googleads.v2.resources.GoogleAdsField.category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectable', full_name='google.ads.googleads.v2.resources.GoogleAdsField.selectable', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filterable', full_name='google.ads.googleads.v2.resources.GoogleAdsField.filterable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortable', full_name='google.ads.googleads.v2.resources.GoogleAdsField.sortable', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectable_with', full_name='google.ads.googleads.v2.resources.GoogleAdsField.selectable_with', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_resources', full_name='google.ads.googleads.v2.resources.GoogleAdsField.attribute_resources', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.ads.googleads.v2.resources.GoogleAdsField.metrics', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='google.ads.googleads.v2.resources.GoogleAdsField.segments', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_values', full_name='google.ads.googleads.v2.resources.GoogleAdsField.enum_values', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='google.ads.googleads.v2.resources.GoogleAdsField.data_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='google.ads.googleads.v2.resources.GoogleAdsField.type_url', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_repeated', full_name='google.ads.googleads.v2.resources.GoogleAdsField.is_repeated', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=1086,
)

_GOOGLEADSFIELD.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['category'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__category__pb2._GOOGLEADSFIELDCATEGORYENUM_GOOGLEADSFIELDCATEGORY
_GOOGLEADSFIELD.fields_by_name['selectable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['filterable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['sortable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['selectable_with'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['attribute_resources'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['metrics'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['segments'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['enum_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['data_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2._GOOGLEADSFIELDDATATYPEENUM_GOOGLEADSFIELDDATATYPE
_GOOGLEADSFIELD.fields_by_name['type_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['is_repeated'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['GoogleAdsField'] = _GOOGLEADSFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GoogleAdsField = _reflection.GeneratedProtocolMessageType('GoogleAdsField', (_message.Message,), dict(
  DESCRIPTOR = _GOOGLEADSFIELD,
  __module__ = 'google.ads.googleads_v2.proto.resources.google_ads_field_pb2'
  ,
  __doc__ = """A field or resource (artifact) used by GoogleAdsService.
  
  
  Attributes:
      resource_name:
          The resource name of the artifact. Artifact resource names
          have the form:  ``googleAdsFields/{name}``
      name:
          The name of the artifact.
      category:
          The category of the artifact.
      selectable:
          Whether the artifact can be used in a SELECT clause in search
          queries.
      filterable:
          Whether the artifact can be used in a WHERE clause in search
          queries.
      sortable:
          Whether the artifact can be used in a ORDER BY clause in
          search queries.
      selectable_with:
          The names of all resources, segments, and metrics that are
          selectable with the described artifact.
      attribute_resources:
          The names of all resources that are selectable with the
          described artifact. Fields from these resources do not segment
          metrics when included in search queries.  This field is only
          set for artifacts whose category is RESOURCE.
      metrics:
          At and beyond version V1 this field lists the names of all
          metrics that are selectable with the described artifact when
          it is used in the FROM clause. It is only set for artifacts
          whose category is RESOURCE.  Before version V1 this field
          lists the names of all metrics that are selectable with the
          described artifact. It is only set for artifacts whose
          category is either RESOURCE or SEGMENT
      segments:
          At and beyond version V1 this field lists the names of all
          artifacts, whether a segment or another resource, that segment
          metrics when included in search queries and when the described
          artifact is used in the FROM clause. It is only set for
          artifacts whose category is RESOURCE.  Before version V1 this
          field lists the names of all artifacts, whether a segment or
          another resource, that segment metrics when included in search
          queries. It is only set for artifacts of category RESOURCE,
          SEGMENT or METRIC.
      enum_values:
          Values the artifact can assume if it is a field of type ENUM.
          This field is only set for artifacts of category SEGMENT or
          ATTRIBUTE.
      data_type:
          This field determines the operators that can be used with the
          artifact in WHERE clauses.
      type_url:
          The URL of proto describing the artifact's data type.
      is_repeated:
          Whether the field artifact is repeated.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.GoogleAdsField)
  ))
_sym_db.RegisterMessage(GoogleAdsField)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/change_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import change_status_operation_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__operation__pb2
from google.ads.google_ads.v2.proto.enums import change_status_resource_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__resource__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/change_status.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\021ChangeStatusProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n;google/ads/googleads_v2/proto/resources/change_status.proto\x12!google.ads.googleads.v2.resources\x1a\x41google/ads/googleads_v2/proto/enums/change_status_operation.proto\x1a\x45google/ads/googleads_v2/proto/enums/change_status_resource_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc3\x06\n\x0c\x43hangeStatus\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12;\n\x15last_change_date_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12k\n\rresource_type\x18\x04 \x01(\x0e\x32T.google.ads.googleads.v2.enums.ChangeStatusResourceTypeEnum.ChangeStatusResourceType\x12.\n\x08\x63\x61mpaign\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x61\x64_group\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12g\n\x0fresource_status\x18\x08 \x01(\x0e\x32N.google.ads.googleads.v2.enums.ChangeStatusOperationEnum.ChangeStatusOperation\x12\x31\n\x0b\x61\x64_group_ad\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x61\x64_group_criterion\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x63\x61mpaign_criterion\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x66\x65\x65\x64\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfeed_item\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rad_group_feed\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rcampaign_feed\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15\x61\x64_group_bid_modifier\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfe\x01\n%com.google.ads.googleads.v2.resourcesB\x11\x43hangeStatusProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__operation__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__resource__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CHANGESTATUS = _descriptor.Descriptor(
  name='ChangeStatus',
  full_name='google.ads.googleads.v2.resources.ChangeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.ChangeStatus.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_change_date_time', full_name='google.ads.googleads.v2.resources.ChangeStatus.last_change_date_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='google.ads.googleads.v2.resources.ChangeStatus.resource_type', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v2.resources.ChangeStatus.campaign', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v2.resources.ChangeStatus.ad_group', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_status', full_name='google.ads.googleads.v2.resources.ChangeStatus.resource_status', index=5,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad', full_name='google.ads.googleads.v2.resources.ChangeStatus.ad_group_ad', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion', full_name='google.ads.googleads.v2.resources.ChangeStatus.ad_group_criterion', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion', full_name='google.ads.googleads.v2.resources.ChangeStatus.campaign_criterion', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.resources.ChangeStatus.feed', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item', full_name='google.ads.googleads.v2.resources.ChangeStatus.feed_item', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_feed', full_name='google.ads.googleads.v2.resources.ChangeStatus.ad_group_feed', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_feed', full_name='google.ads.googleads.v2.resources.ChangeStatus.campaign_feed', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_bid_modifier', full_name='google.ads.googleads.v2.resources.ChangeStatus.ad_group_bid_modifier', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=1134,
)

_CHANGESTATUS.fields_by_name['last_change_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['resource_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__resource__type__pb2._CHANGESTATUSRESOURCETYPEENUM_CHANGESTATUSRESOURCETYPE
_CHANGESTATUS.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['resource_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_change__status__operation__pb2._CHANGESTATUSOPERATIONENUM_CHANGESTATUSOPERATION
_CHANGESTATUS.fields_by_name['ad_group_ad'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['ad_group_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['campaign_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['feed_item'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['ad_group_feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['campaign_feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGESTATUS.fields_by_name['ad_group_bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['ChangeStatus'] = _CHANGESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangeStatus = _reflection.GeneratedProtocolMessageType('ChangeStatus', (_message.Message,), dict(
  DESCRIPTOR = _CHANGESTATUS,
  __module__ = 'google.ads.googleads_v2.proto.resources.change_status_pb2'
  ,
  __doc__ = """Describes the status of returned resource.
  
  
  Attributes:
      resource_name:
          The resource name of the change status. Change status resource
          names have the form:
          ``customers/{customer_id}/changeStatus/{change_status_id}``
      last_change_date_time:
          Time at which the most recent change has occurred on this
          resource.
      resource_type:
          Represents the type of the changed resource. This dictates
          what fields will be set. For example, for AD\_GROUP, campaign
          and ad\_group fields will be set.
      campaign:
          The Campaign affected by this change.
      ad_group:
          The AdGroup affected by this change.
      resource_status:
          Represents the status of the changed resource.
      ad_group_ad:
          The AdGroupAd affected by this change.
      ad_group_criterion:
          The AdGroupCriterion affected by this change.
      campaign_criterion:
          The CampaignCriterion affected by this change.
      feed:
          The Feed affected by this change.
      feed_item:
          The FeedItem affected by this change.
      ad_group_feed:
          The AdGroupFeed affected by this change.
      campaign_feed:
          The CampaignFeed affected by this change.
      ad_group_bid_modifier:
          The AdGroupBidModifier affected by this change.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.ChangeStatus)
  ))
_sym_db.RegisterMessage(ChangeStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
